<?php

/**
 * @file
 * Contains administrative functions for the Entitlements module.
 */

/**
 * Display a report of entitlements providers, consumers, and mapping
 * statistics.
 */
function entitlements_report() {
  $output = '';

  // Show a list of providers
  $providers = Entitlements::getProviderInfo();
  $rows = array();
  foreach ($providers as $provider => $info) {
    $rows[] = array($provider, $info['description']);
  }

  $output .= '<h3>' . t('Providers') . '</h3>';
  $output .= theme('table', array(
    'header' => array(t('Provider'), t('Description')),
    'rows' => $rows,
    'empty' => t('No entitlements providers available.'),
  ));

  // Show a list of consumers
  $consumers = Entitlements::getConsumerInfo();
  $rows = array();
  foreach ($consumers as $consumer => $info) {
    $rows[] = array($consumer, $info['description']);
  }

  $output .= '<h3>' . t('Consumers') . '</h3>';
  $output .= theme('table', array(
    'header' => array(t('Consumer'), t('Description')),
    'rows' => $rows,
    'empty' => t('No entitlements consumers available.'),
  ));

  // Get aggregated list of entitlements
  $mappings = array();
  $q = db_select('entitlements', 'e')
    ->fields('e', array('provider', 'realm', 'name'))
    ->groupBy('provider', 'realm', 'name')
    ->orderBy('uid_count', 'DESC');
  $q->addExpression('COUNT(uid)', 'uid_count');
  foreach ($q->execute() as $mapping) {
    if ($mapping->uid_count > 0) {
      $mappings[] = array($mapping->provider, $mapping->realm, $mapping->name, $mapping->uid_count);
    }
  }

  // Get total number of entitlements
  $total = db_select('entitlements', 'e')
    ->countQuery()
    ->execute()
    ->fetchField();

  $output .= '<h3>' . t('Mappings') . '</h3>';
  $output .= theme('table', array(
    'header' => array(t('Provider'), t('Realm'), t('Entitlement'), t('Count')),
    'rows' => $mappings,
    'caption' => t('%total entitlement(s) assigned.', array('%total' => $total)),
    'empty' => t('No entitlements assigned.'),
  ));

  return $output;
}
